#ifndef NT2_INCLUDE_FUNCTIONS_FUZZY_GREATER_OR_EQUAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FUZZY_GREATER_OR_EQUAL_HPP_INCLUDED

#include <nt2/fuzzy/include/functions/fuzzy_greater_or_equal.hpp>

#endif
